# PerTunnelStats

Tunnel Statistics

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ip_address** | **str** | The IP address from which the connector established this tunnel. | 
**tunnel_host** | **str** | The hostname of the cluster the connector connects to. | [optional] 
**index** | **str** | The index of the router instance within its cluster | [optional] 
**connected** | **bool** | Whether or not the tunnel is currently connected  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


